import AdminUserModel from '~/business-logic/generic/admin-user/common/data/model/adminUserModel';
import { AdminOtpData } from '../../usecase/otpAuthUsecase';
import otpAuthRO, { OtpAuthResponse } from '../reponse-object/otpAuthRO';
import OtpAuthDTO, { OtpAuthDTOReturnType } from '../dto/otpAuthDto';
import IOtpAuthRepo from './IOtpAuthRepo';

export type OtpHttpHandler = (data: OtpAuthDTOReturnType) => Promise<OtpAuthResponse>;

export default class OtpAuthRepo implements IOtpAuthRepo {
  private httpHandler: OtpHttpHandler;

  constructor(httpHandler: OtpHttpHandler) {
    this.httpHandler = httpHandler;
  }

  async execute(otpData: AdminOtpData): Promise<AdminUserModel> {
    // call dto
    const dto = OtpAuthDTO(otpData);
    // call handler
    const response = await this.httpHandler(dto);
    // call ro
    const responseObjectData = {
      ...response,
      phonenumber: otpData.phonenumber,
    };
    const responseObject = otpAuthRO(responseObjectData);
    // make model
    const adminModel = new AdminUserModel(responseObject);
    // return model
    return adminModel;
  }
}
