import AdminUserModel from '~/business-logic/generic/admin-user/common/data/model/adminUserModel';
import { HTTPPovider } from '~/driven/boundaries/http-boundary/httpBoundary';
import { HttpOptionsType } from '~/driven/boundaries/http-boundary/protocols';
import { apiUrls } from '~/driven/utils/configs/appConfig';
import {
  ICreatePlaceLogicMaker,
  createPlaceArguments,
} from '~/driving/application/core/places/create-place/model/submiCreatePlace';

const createPlacesDto = (newPlace: createPlaceArguments) => ({
  place_type: newPlace.placeType,
  parent_id: newPlace.parentId || null,
  name: newPlace.placeName,
});

const createPlaceAdapter = (
  userAdmin: AdminUserModel | null,
  updateAccessToken: (newAccessToken: string) => void,
  navigateToAuth: () => void,
): ICreatePlaceLogicMaker => {
  const url = apiUrls.core.createPlace;
  const httpHandler = async (newPlace: createPlaceArguments) => {
    const httpProvider = new HTTPPovider(
      {
        accessToken: (userAdmin && userAdmin?.adminUserData.accessToken) || null,
        refreshToken: (userAdmin && userAdmin?.adminUserData.refreshToken) || null,
      },
      updateAccessToken,
      navigateToAuth,
    );
    const dto = createPlacesDto(newPlace);
    const options: HttpOptionsType = {
      url,
      method: 'POST',
      data: dto,
    };

    return await httpProvider.request<string>(options);
  };
  return {
    httpHandler,
  };
};

export default createPlaceAdapter;
