/* eslint-disable import/no-extraneous-dependencies */
import React from 'react';
import Select from 'react-select';
import InputWrapper, { IInputWrapper } from '../input-wrapper/InputWrapper';

interface IInputBox<ValueType> extends IInputWrapper {
  name: string;
  state: {
    value: { value: ValueType; label: string };
    options: { value: ValueType; label: string }[];
    setValue: (newValue: ValueType, label: string) => void;
    isLoading?: boolean;
  };
}

export default function InputBox<ValueType>(props: IInputBox<ValueType>) {
  const { title, className, name, state } = props;
  const { setValue, value, options } = state;
  return (
    <InputWrapper title={title} className={className}>
      <Select
        classNamePrefix='select'
        defaultValue={value}
        value={value}
        isLoading={state.isLoading}
        onChange={(newValue) => newValue && newValue.value && setValue(newValue.value, newValue.label)}
        isSearchable
        name={name}
        options={options}
        className='text-txt-medium'
      />
    </InputWrapper>
  );
}
