import Places from '~/business-logic/core/places/common/entity/placeEntity';
import PlacesModel from '~/business-logic/core/places/common/model/placesModel';
import { staticMessages } from '~/driven/utils/constants/staticMessages';
import { placeTypes } from '../view/protocol';

export const placeTypeTuple: ReadonlyArray<`${placeTypes}`> = [
  placeTypes.continent,
  placeTypes.country,
  placeTypes.state,
  placeTypes.region,
  placeTypes.city,
  placeTypes.district,
  placeTypes.street,
  placeTypes.building,
  placeTypes.section,
  placeTypes.floor,
  placeTypes.flat,
];

const makeOptionsOfSelectBoxForParentIds = (places: Places[], currentPlaceType: `${placeTypes}`) => {
  const currentPlaceTypeIndex = placeTypeTuple.indexOf(currentPlaceType);
  if (currentPlaceTypeIndex === -1) throw new Error();

  const placesValidToShow = places.reduce((prevVal, currentVal) => {
    const placeListItemIndex = placeTypeTuple.indexOf(currentVal.placeType as `${placeTypes}`);

    if (!currentVal.parentId) return prevVal;

    if (placeListItemIndex === -1) return prevVal;
    if (placeListItemIndex > currentPlaceTypeIndex) return prevVal;

    const label = `${currentVal.placeType} ${currentVal.name}`;
    return [...prevVal, { value: currentVal.parentId, label }];
  }, <{ value: string; label: string }[]>[]);

  return placesValidToShow;
};
const getValidParentIdsOptionsOfSelectBox = (
  currentPlaceType: `${placeTypes}`,
  placesList: PlacesModel,
): { value: string; label: string }[] => {
  try {
    if (!placesList) throw new Error();
    const places = placesList.getData();
    if (!places.length) throw new Error();

    const placesOptionsValidToShow = makeOptionsOfSelectBoxForParentIds(places, currentPlaceType);

    return placesOptionsValidToShow;
  } catch (_error) {
    return [];
  }
};

const getPlacesTypeOptionsOfSelectBox = () => {
  return Object.keys(placeTypes).map((placeTypeKey) => {
    const key = placeTypeKey as keyof typeof placeTypes;

    return { value: placeTypes[key], label: staticMessages.placeTypes[placeTypes[key]] };
  });
};

export default {
  getValidParentIdsOptionsOfSelectBox,
  getPlacesTypeOptionsOfSelectBox,
};
