import React from 'react';
import SimpleInput from '~/driven/utils/components/inputs/simple-input/SimpleInput';
import InputBox from '~/driven/utils/components/inputs/select-box/InputBox';
import { staticMessages } from '~/driven/utils/constants/staticMessages';
import PrimaryButton from '~/driven/utils/components/buttons/primary-button/PrimaryButton';
import Notification from '~/driven/utils/components/Notification/Notification';
import { ICreatePlaceProps } from './protocol';

export default function CreatePlaceView(props: ICreatePlaceProps) {
  const { formStateData, inputStateHandlers, inputOptions, handleSubmitCreatePlaceForm } = props;
  const { formState, error, setError } = formStateData;

  return (
    <>
      {Boolean(error.message) && (
        <Notification
          message={error.message}
          type={error.type}
          onCloseCallback={() => setError({ message: '', type: 'error' })}
        />
      )}
      <form onSubmit={handleSubmitCreatePlaceForm} className='p-4 py-6 flex flex-wrap w-full gap-4'>
        <SimpleInput
          inputData={{
            name: staticMessages.global.PlaceName,
            title: staticMessages.global.PlaceName,
          }}
          stateHanlder={{
            state: formState.placeName,
            setState: inputStateHandlers.name,
          }}
          className='mb-4 w-[48%] px-2'
        />
        <InputBox
          name={staticMessages.global.placeType}
          state={{
            value: { value: formState.placeTypes, label: staticMessages.placeTypes[formState.placeTypes] },
            setValue: inputStateHandlers.placeType,
            options: inputOptions.placeType,
          }}
          title={staticMessages.global.placeType}
          className='mb-4 w-[48%] px-2 border-1 border-txt-medium text-txt-medium'
        />
        <InputBox
          name={staticMessages.global.placeParentId}
          state={{
            value: { value: formState.parentId.value, label: formState.parentId.label },
            setValue: inputStateHandlers.parentId,
            options: inputOptions.parentId,
            isLoading: inputOptions.isParentIdLoading,
          }}
          title={staticMessages.global.placeParentId}
          className='mb-4 w-[48%] px-2 border-1 border-txt-medium text-txt-medium'
        />
        <div className='w-full'>
          <PrimaryButton onClick={() => null} title={staticMessages.global.submit} />
        </div>
      </form>
    </>
  );
}
