import React, { useMemo } from 'react';
import { staticMessages } from '~/driven/utils/constants/staticMessages';
import Loading from '~/driven/utils/components/loading/Loading';
import TableRow from '../../../common/table-row';
import { IPlacesListProps } from './protocols';

export default function PlacesListView(props: IPlacesListProps) {
  const { selectedRowId, setSelectedRowId, placesList } = props;

  const rows = useMemo(() => {
    if (!placesList.data) return null;

    return placesList.data.getData().map((places) => {
      const rowData = {
        rowItemsTitle: [places.name, places.placeType, places.qr],
        rowId: places.id,
      };
      return (
        <TableRow
          key={rowData.rowId}
          rowData={rowData}
          selectedRowId={selectedRowId}
          setSelectedRowId={setSelectedRowId}
        />
      );
    });
  }, [placesList]);

  if (placesList.isLoading)
    return (
      <div className='flex justify-center items-center'>
        <Loading />
      </div>
    );
  const tableTitles = {
    name: staticMessages.global.title,
    placeType: staticMessages.global.placeType,
    qr: staticMessages.global.qrCode,
  };

  const titles = Object.keys(tableTitles).map((titleKey) => {
    const key = titleKey as keyof typeof tableTitles;

    const title = tableTitles[key];
    return (
      <th key={key} className='py-3'>
        {title}
      </th>
    );
  });
  return (
    <table className='table-auto rounded-md w-full text-sm h-fit'>
      <thead className='text-txt-medium font-bold'>
        <tr>{titles}</tr>
      </thead>
      <tbody>{rows}</tbody>
    </table>
  );
}
